'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _cfComponentPagination = require('cf-component-pagination');

var _cfComponentIcon = require('cf-component-icon');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class PaginationBuilder extends _react2.default.Component {
  render() {
    const {
      totalCount: totalItems,
      page,
      perPage,
      infoFormatter,
      loading,
      onPageChange
    } = this.props;

    const totalPages = Math.ceil(totalItems / perPage);
    const pageIndex = this.props.page - 1;
    const start = Math.max(pageIndex * perPage + 1, 1);
    const end = Math.min(start + perPage - 1, totalItems);

    const handleClickItem = page => {
      if (page >= 1 && page <= totalPages) {
        onPageChange(page);
      }
    };

    const items = [];

    let prevWasEllipsis = false;

    for (let i = 1; i <= totalPages; i++) {
      if (
      // First Page:
      i === 1 ||
      // Last Page:
      i === totalPages ||
      // Current Page:
      i === page ||
      // Within 2 of page:
      Math.abs(page - i) <= 2 ||
      // Within 3 of page and next to start or end: (Why? Because if we show an ellipsis instead of just a single number then wtf was the point)
      Math.abs(page - i) <= 3 && (i === 2 || i === totalPages - 1)) {
        prevWasEllipsis = false;
        items.push(_react2.default.createElement(
          _cfComponentPagination.PaginationItem,
          {
            key: i,
            type: loading && page === i ? 'loading' : 'number',
            label: 'Page ' + i,
            active: page === i,
            onClick: () => handleClickItem(i)
          },
          i
        ));
      } else if (!prevWasEllipsis) {
        prevWasEllipsis = true;
        items.push(_react2.default.createElement(_cfComponentPagination.PaginationItem, {
          key: i,
          type: 'ellipsis',
          label: 'Page ' + i,
          onClick: () => null
        }));
      }
    }

    const info = infoFormatter && infoFormatter(start, end, totalItems);

    return _react2.default.createElement(
      _cfComponentPagination.Pagination,
      { info: info },
      _react2.default.createElement(
        _cfComponentPagination.PaginationItem,
        {
          type: 'prev',
          label: 'Previous Page',
          disabled: page === 1,
          onClick: () => handleClickItem(page - 1)
        },
        _react2.default.createElement(_cfComponentIcon.Icon, {
          color: page === 1 ? 'default' : 'white',
          type: 'caret-left',
          label: false
        })
      ),
      items,
      _react2.default.createElement(
        _cfComponentPagination.PaginationItem,
        {
          type: 'next',
          label: 'Next Page',
          disabled: page === totalPages,
          onClick: () => handleClickItem(page + 1)
        },
        _react2.default.createElement(_cfComponentIcon.Icon, {
          type: 'caret-right',
          color: page === totalPages ? 'default' : 'white',
          label: false
        })
      )
    );
  }
}

PaginationBuilder.propTypes = {
  onPageChange: _propTypes2.default.func.isRequired,
  loading: _propTypes2.default.bool,

  totalCount: _propTypes2.default.number.isRequired,
  page: _propTypes2.default.number.isRequired,
  perPage: _propTypes2.default.number.isRequired,

  infoFormatter: _propTypes2.default.func
};

exports.default = PaginationBuilder;